@@ -4,6 +4,7 @@
 #include <algorithm>
 #include <string>
 
+#include "attribute.h"
 #include "client.h"
 #include "completion.h"
 #include "decoration.h"
@@ -29,6 +30,9 @@ using std::vector;
 ClientManager::ClientManager()
     : focus(*this, "focus")
     , dragged(*this, "dragged")
+    , theme(nullptr)
+    , settings(nullptr)
+    , ewmh(nullptr)
 {
 }
 
@@ -55,8 +59,9 @@ void ClientManager::injectDependencies(Settings* s, Theme* t, Ewmh* e) {
 Client* ClientManager::client(Window window)
 {
     auto entry = clients_.find(window);
-    if (entry != clients_.end())
+    if (entry != clients_.end()) {
         return entry->second;
+    }
     return {};
 }
 
@@ -76,8 +81,9 @@ Client* ClientManager::client(const string &identifier)
     }
     if (identifier == "urgent") {
         for (auto c : clients_) {
-            if (c.second->urgent_)
+            if (c.second->urgent_) {
                 return c.second;
+            }
         }
         return {}; // no urgent client found
     }
@@ -355,7 +361,7 @@ int ClientManager::applyRules(Client* client, Output output, bool changeFocus)
             }
         }
     }
-    if (tag || changes.tree_index != "") {
+    if (tag || !changes.tree_index.empty()) {
         if (!tag) {
             tag = client->tag();
         }
@@ -429,9 +435,11 @@ int ClientManager::clientSetAttribute(string attribute,
     Client* c = get_current_client();
     if (c) {
         Attribute* a = c->attribute(attribute);
-        if (!a) return HERBST_UNKNOWN_ERROR;
+        if (!a) {
+            return HERBST_UNKNOWN_ERROR;
+        }
         string error_message = a->change(value);
-        if (error_message != "") {
+        if (!error_message.empty()) {
             output << input.command() << ": illegal argument \""
                    << value << "\": "
                    << error_message << endl;
