@@ -13,29 +13,35 @@ Input &Input::operator>>(string &val)
 Input Input::fromHere()
 {
     string cmd;
-    if (!(*this >> cmd))
+    if (!(*this >> cmd)) {
         return {{}, {}};
+    }
 
     return Input(cmd, toVector());
 }
 
 void Input::replace(const string &from, const string &to)
 {
-    for (auto &v : *container_)
-        if (v == from)
+    for (auto &v : *container_) {
+        if (v == from) {
             v = to;
+        }
 
-    if (*command_ == from)
-        *command_ = to;
+        if (*command_ == from) {
+            *command_ = to;
+        }
+    }
 }
 
 template<> void Converter<bool>::complete(Completion& complete, bool const* relativeTo)
 {
     complete.full({ "on", "off", "true", "false" });
-    if (relativeTo) complete.full("toggle");
+    if (relativeTo != nullptr) {
+        complete.full("toggle");
+    }
 }
 
-void completeFull(Completion &complete, std::string s)
+void completeFull(Completion &complete, string s)
 {
     complete.full(s);
 }
@@ -47,9 +53,9 @@ void Converter<Direction>::complete(Completion& complete, const Direction* relat
 }
 
 template<>
-unsigned long Converter<unsigned long>::parse(const std::string& payload)
+unsigned long Converter<unsigned long>::parse(const string& source)
 {
-    long value = std::stol(payload);
+    long value = std::stol(source);
     if (value < 0) {
         throw std::invalid_argument("negative number is out of range");
     } else {
