@@ -1,13 +1,12 @@
-#! /usr/bin/env python2
+#!/usr/bin/env python3
 
 import sys
 import datetime
-import types
 from collections import OrderedDict
 
 tabs = OrderedDict([
     ("Overview", OrderedDict([
-        ("index",""),
+        ("index", ""),
     ])),
     ("Documentation", OrderedDict([
         ("news", "News"),
@@ -22,7 +21,7 @@ tabs = OrderedDict([
     ("Download", OrderedDict([
         ("download", "Download"),
     ])),
-    ("Wiki", "http://wiki.herbstluftwm.org"),
+    # ("Wiki", "http://wiki.herbstluftwm.org"),
 ])
 
 page2tab = {
@@ -34,9 +33,9 @@ name = filename.replace('-content.html', '')
 toc = filename.replace('-content.html', '-toc.html')
 
 windowtitle = "herbstluftwm"
-for title, subpages in tabs.iteritems():
-    if not isinstance(subpages, basestring):
-        for fn, subtitle in subpages.iteritems():
+for title, subpages in tabs.items():
+    if not isinstance(subpages, str):
+        for fn, subtitle in subpages.items():
             page2tab[fn] = title
             if not ("" == subtitle) and (name == fn):
                 windowtitle = subtitle + " - herbstluftwm"
@@ -44,14 +43,15 @@ for title, subpages in tabs.iteritems():
 
 curtab = page2tab[name]
 
-#====~===~=========~==
+# ====~===~=========~==
 # Header
-#====~===~=========~==
-print """\
+# ====~===~=========~==
+print("""\
 <html>
  <head>
   <link rel="stylesheet" href="main.css" type="text/css" />
   <meta http-equiv="Content-Type" content="application/xhtml+xml; charset=UTF-8" />
+  <meta name="viewport" content="width=device-width, initial-scale=1">
   <title>{title}</title>
  </head>
  <body>
@@ -66,78 +66,76 @@ print """\
        </div>
      </div>
     </div>
-   </div>""".format(title=windowtitle)
+   </div>""".format(title=windowtitle))
 
-#====~===~=========~==
+# ====~===~=========~==
 # Navigation bar
-#====~===~=========~==
+# ====~===~=========~==
 
-print """\
-    <ul id="navigationbar">"""
+print("""\
+    <ul id="navigationbar">""")
 
-for title, subpages in tabs.iteritems():
+for title, subpages in tabs.items():
     classstring = "notab"
     if title == curtab:
         classstring = "curtab"
-    if isinstance(subpages, basestring):
+    if isinstance(subpages, str):
         trg = subpages
     else:
-        trg = subpages.keys()[0] + ".html"
-    print '<li class="{cls}"><a href="{target}">{title}</a></li>'.format(
-        cls = classstring,
-        target = trg,
-        title = title)
+        trg = list(subpages.keys())[0] + ".html"
+    print('<li class="{cls}"><a href="{target}">{title}</a></li>'.format(
+        cls=classstring,
+        target=trg,
+        title=title))
 
 
-print """\
+print("""\
     </ul>\
     <div class="tabbarseparator"></div>
-"""
+""")
 
 subpages = tabs.get(page2tab[name], OrderedDict([]))
 
 if len(subpages) > 1:
-    print '<div class="subpagebar">'
-    for basename, title in subpages.iteritems():
+    print('<div class="subpagebar">')
+    for basename, title in subpages.items():
         if basename == name:
             cls = "subpagecur subpage"
         else:
             cls = "subpage"
-        print '<span class="{cls}">'.format(cls = cls)
-        print '<a href="{url}">{title}</a></span>'.format(
-            url = basename + ".html",title = title)
-    print "</div>"
+        print('<span class="{cls}">'.format(cls=cls))
+        print('<a href="{url}">{title}</a></span>'.format(
+            url=basename + ".html", title=title))
+    print("</div>")
 
-
-
-print """\
+print("""\
     <div id="content">\
-"""
+""")
 
 # possibly table of contents:
 try:
-	print open(toc).read()
+    print(open(toc).read())
 except IOError:
-	# no toc file
-	print "<!-- no toc file present -->"
-print open(filename).read()
+    # no toc file
+    print("<!-- no toc file present -->")
+print(open(filename).read())
 
 
-print """\
+print("""\
     <div class="footer">
       Generated on {date}
      - <a href=\"imprint.html\">Imprint and Privacy Policy</a>
     </div>
-""".format(date=datetime.datetime.now().strftime('%Y-%m-%d at %H:%M:%S %Z'))
+""".format(date=datetime.datetime.now().strftime('%Y-%m-%d at %H:%M:%S %Z')))
 
-#====~===~=========~==
+# ====~===~=========~==
 # Footer
-#====~===~=========~==
-print """\
+# ====~===~=========~==
+print("""\
    </div>
   </div>
  </body>
 </html>
-"""
+""")
 
 # vim: noet
